Displays a brief summary of the population treatment effect posterior.
Usage
# S3 method for class 'meta_did_fit'
print(x, prob = 0.9, ...)Displays a brief summary of the population treatment effect posterior.
# S3 method for class 'meta_did_fit'
print(x, prob = 0.9, ...)