Returns a data frame of posterior summaries for the population-level treatment effect parameters and each study-level treatment effect.
Usage
# S3 method for class 'meta_did_fit'
summary(object, prob = 0.9, ...)Returns a data frame of posterior summaries for the population-level treatment effect parameters and each study-level treatment effect.
# S3 method for class 'meta_did_fit'
summary(object, prob = 0.9, ...)