Checks that data meets the structural requirements for use in
meta_did(). Called automatically inside meta_did(); also useful for
diagnosing problems before fitting.
Checks that data meets the structural requirements for use in
meta_did(). Called automatically inside meta_did(); also useful for
diagnosing problems before fitting.